==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/NamedTagEventListBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class NamedTagEventListBuilder extends io.fabric8.openshift.api.model.NamedTagEventListFluentImpl<io.fabric8.openshift.api.model.NamedTagEventListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.NamedTagEventList,io.fabric8.openshift.api.model.NamedTagEventListBuilder>{
  public NamedTagEventListBuilder() {
    this(false);
  }
  public NamedTagEventListBuilder(java.lang.Boolean validationEnabled) {
    this(new NamedTagEventList(), validationEnabled);
  }
  public NamedTagEventListBuilder(io.fabric8.openshift.api.model.NamedTagEventListFluent<?> fluent) {
    this(fluent, false);
  }
  public NamedTagEventListBuilder(io.fabric8.openshift.api.model.NamedTagEventListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new NamedTagEventList(), validationEnabled);
  }
  public NamedTagEventListBuilder(io.fabric8.openshift.api.model.NamedTagEventListFluent<?> fluent,io.fabric8.openshift.api.model.NamedTagEventList instance) {
    this(fluent, instance, false);
  }
  public NamedTagEventListBuilder(io.fabric8.openshift.api.model.NamedTagEventListFluent<?> fluent,io.fabric8.openshift.api.model.NamedTagEventList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConditions(instance.getConditions()); 
    fluent.withItems(instance.getItems()); 
    fluent.withTag(instance.getTag()); 
    this.validationEnabled = validationEnabled; 
  }
  public NamedTagEventListBuilder(io.fabric8.openshift.api.model.NamedTagEventList instance) {
    this(instance,false);
  }
  public NamedTagEventListBuilder(io.fabric8.openshift.api.model.NamedTagEventList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withConditions(instance.getConditions()); 
    this.withItems(instance.getItems()); 
    this.withTag(instance.getTag()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.NamedTagEventListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.NamedTagEventList build() {
    NamedTagEventList buildable = new NamedTagEventList(fluent.getConditions(),fluent.getItems(),fluent.getTag());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NamedTagEventListBuilder that = (NamedTagEventListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/NamedTagEventListBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class NamedTagEventListBuilder extends io.fabric8.openshift.api.model.NamedTagEventListFluentImpl<io.fabric8.openshift.api.model.NamedTagEventListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.NamedTagEventList,io.fabric8.openshift.api.model.NamedTagEventListBuilder>{
  public NamedTagEventListBuilder() {
    this(false);
  }
  public NamedTagEventListBuilder(java.lang.Boolean validationEnabled) {
    this(new NamedTagEventList(), validationEnabled);
  }
  public NamedTagEventListBuilder(io.fabric8.openshift.api.model.NamedTagEventListFluent<?> fluent) {
    this(fluent, false);
  }
  public NamedTagEventListBuilder(io.fabric8.openshift.api.model.NamedTagEventListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new NamedTagEventList(), validationEnabled);
  }
  public NamedTagEventListBuilder(io.fabric8.openshift.api.model.NamedTagEventListFluent<?> fluent,io.fabric8.openshift.api.model.NamedTagEventList instance) {
    this(fluent, instance, false);
  }
  public NamedTagEventListBuilder(io.fabric8.openshift.api.model.NamedTagEventListFluent<?> fluent,io.fabric8.openshift.api.model.NamedTagEventList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConditions(instance.getConditions()); 
    fluent.withItems(instance.getItems()); 
    fluent.withTag(instance.getTag()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public NamedTagEventListBuilder(io.fabric8.openshift.api.model.NamedTagEventList instance) {
    this(instance,false);
  }
  public NamedTagEventListBuilder(io.fabric8.openshift.api.model.NamedTagEventList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withConditions(instance.getConditions()); 
    this.withItems(instance.getItems()); 
    this.withTag(instance.getTag()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.NamedTagEventListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.NamedTagEventList build() {
    NamedTagEventList buildable = new NamedTagEventList(fluent.getConditions(),fluent.getItems(),fluent.getTag());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NamedTagEventListBuilder that = (NamedTagEventListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
